OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Не могу да пошаљем е-пошту следећим корисницима: %s ",
    "Preparing update" : "Припремам надоградњу",
    "Turned on maintenance mode" : "Режим одржавања укључен",
    "Turned off maintenance mode" : "Режим одржавања искључен",
    "Maintenance mode is kept active" : "Режим одржавања се држи активним",
    "Updated database" : "База података ажурирана",
    "Checked database schema update" : "Ажурирање шеме базе података, проверено",
    "Checked database schema update for apps" : "Ажурирање шеме базе података за апликације, проверено",
    "Updated \"%s\" to %s" : "„%s“ ажириран на %s",
    "Repair warning: " : "Упозорење о поправци :",
    "Repair error: " : "Грешка поправке:",
    "Following apps have been disabled: %s" : "Следеће апликације су искључене: %s",
    "File is too big" : "Фајл је превелик",
    "Invalid file provided" : "Понуђени фајл је неисправан",
    "No image or file provided" : "Није дата ни слика ни фајл",
    "Unknown filetype" : "Непознат тип фајла",
    "Invalid image" : "Неисправна слика",
    "No temporary profile picture available, try again" : "Нема привремене слике профила. Покушајте поново",
    "No crop data provided" : "Нема података о опсецању",
    "No valid crop data provided" : "Нема података о опсецању",
    "Crop is not square" : "Опсецање није квадрат",
    "Couldn't reset password because the token is invalid" : "Није могуће ресетовати лозинку јер je токен неважећи",
    "Couldn't send reset email. Please make sure your username is correct." : "Не могу да пошаљем поруку за ресетовање лозинке. Проверите да ли је корисничко име исправно.",
    "%s password reset" : "%s лозинка ресетована",
    "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем е-пошту за ресетовање лозинке. Контактирајте администратора.",
    "Sunday" : "недеља",
    "Monday" : "понедељак",
    "Tuesday" : "уторак",
    "Wednesday" : "среда",
    "Thursday" : "четвртак",
    "Friday" : "петак",
    "Saturday" : "субота",
    "Sun." : "нед",
    "Mon." : "пон",
    "Tue." : "уто",
    "Wed." : "сре",
    "Thu." : "чет",
    "Fri." : "пет",
    "Sat." : "суб",
    "Su" : "Не",
    "Mo" : "По",
    "Tu" : "Ут",
    "We" : "Ср",
    "Th" : "Че",
    "Fr" : "Пе",
    "Sa" : "Су",
    "January" : "јануар",
    "February" : "фебруар",
    "March" : "март",
    "April" : "април",
    "May" : "мај",
    "June" : "јун",
    "July" : "јул",
    "August" : "август",
    "September" : "септембар",
    "October" : "октобар",
    "November" : "новембар",
    "December" : "децембар",
    "Jan." : "јан",
    "Feb." : "феб",
    "Mar." : "мар",
    "Apr." : "апр",
    "May." : "мај",
    "Jun." : "јун",
    "Jul." : "јул",
    "Aug." : "авг",
    "Sep." : "сеп",
    "Oct." : "окт",
    "Nov." : "нов",
    "Dec." : "дец",
    "Settings" : "Поставке",
    "Saving..." : "Уписујем...",
    "Dismiss" : "Откажи",
    "seconds ago" : "пре пар секунди",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Веза за ресетовање лозинке је послата на вашу е-адресу. Ако је не примите ускоро, проверите фасцикле за нежељену пошту.<br>Ако није ни тамо, контактирајте вашег администратора.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Фајлови су вам шифровани. Ако нисте укључили кључ за опоравак, нећете моћи да повратите податке након ресетовања лозинке.<br />Ако нисте сигурни шта да радите, контактирајте администратора пре него што наставите.<br />Да ли желите да наставите?",
    "I know what I'm doing" : "Знам шта радим",
    "Password can not be changed. Please contact your administrator." : "Лозинка се не може променити. Контактирајте администратора.",
    "No" : "Не",
    "Yes" : "Да",
    "Choose" : "Изабери",
    "Error loading file picker template: {error}" : "Грешка при учитавању шаблона бирача фајлова: {error}",
    "Ok" : "У реду",
    "Error loading message template: {error}" : "Грешка при учитавању шаблона поруке: {error}",
    "read-only" : "само-за-читање",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} сукоб фајлова","{count} сукоба фајлова","{count} сукоба фајлова"],
    "One file conflict" : "Један сукоб фајлова",
    "New Files" : "Нови фајлови",
    "Already existing files" : "Постојећи фајлови",
    "Which files do you want to keep?" : "Које фајлове желите да задржите?",
    "If you select both versions, the copied file will have a number added to its name." : "Ако изаберете обе верзије, копираном фајлу ће бити додат број у називу.",
    "Cancel" : "Одустани",
    "Continue" : "Настави",
    "(all selected)" : "(све изабрано)",
    "({count} selected)" : "(изабраних {count})",
    "Error loading file exists template" : "Грешка при учитавању шаблона „Фајл постоји“",
    "Very weak password" : "Веома слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Осредња лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ваш сервер није правилно подешен да омогући синхронизацију фајлова. Изгледа да је ВебДАВ сучеље покварено.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Овај сервер нема везу са интернетом. То значи да неке могућности, попут монтирања спољашњег складишта, обавештења о ажурирању или инсталација апликација треће стране, неће радити. Даљински приступ и слање е-поште, такође неће радити. Предлажемо да омогућите интернет везу за овај сервер ако желите да имате све могућности.",
    "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш директоријум са подацима и ваши фајлови су вероватно доступни са интернета. Фајл .htaccess не ради. Предлажемо да подесите ваш веб сервер на начин да директоријум са подацима не буде доступан или га изместите изван кореног директоријума веб сервера.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "ХТТП заглавље „{header}“ није подешено као „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручујемо да подесите ову поставку.",
    "Shared" : "Дељено",
    "Shared with {recipients}" : "Дељено са {recipients}",
    "Error" : "Грешка",
    "Error while sharing" : "Грешка при дељењу",
    "Error while unsharing" : "Грешка при укидању дељења",
    "Error setting expiration date" : "Грешка при постављању датума истека",
    "The public link will expire no later than {days} days after it is created" : "Јавна веза ће престати да важи {days} дана након стварања",
    "Set expiration date" : "Постави датум истека",
    "Expiration" : "Истиче",
    "Expiration date" : "Датум истека",
    "Choose a password for the public link" : "Одредите лозинку за јавну везу",
    "Sending ..." : "Шаљем...",
    "Email sent" : "Порука је послата",
    "Resharing is not allowed" : "Поновно дељење није дозвољено",
    "Share link" : "Веза дељења",
    "Link" : "Веза",
    "Password protect" : "Заштићено лозинком",
    "Password" : "Лозинка",
    "Allow editing" : "Дозволи уређивање",
    "Email link to person" : "Пошаљи е-поштом",
    "Send" : "Пошаљи",
    "Shared with you and the group {group} by {owner}" : "{owner} дели са вама и са групом {group}.",
    "Shared with you by {owner}" : "{owner} дели са вама",
    "group" : "група",
    "remote" : "удаљени",
    "notify by email" : "обавести е-поштом",
    "Unshare" : "Укини дељење",
    "can share" : "може да дели",
    "can edit" : "може да мења",
    "create" : "направи",
    "change" : "измени",
    "delete" : "обриши",
    "access control" : "права приступа",
    "An error occured. Please try again" : "Дошло је до грешке. Покушајте поново",
    "Share" : "Дели",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поделите са људима у другим облацима користећи синтаксу корисничкоиме@сервер.com/owncloud",
    "Share with users or groups …" : "Дели са корисницима или групама...",
    "Share with users, groups or remote users …" : "Дели са корисницима, групама или удаљеним корисницима...",
    "Warning" : "Упозорење",
    "Delete" : "Обриши",
    "Rename" : "Преименуј",
    "The object type is not specified." : "Тип објекта није наведен.",
    "Enter new" : "Унесите  нови",
    "Add" : "Додај",
    "Edit tags" : "Уреди ознаке",
    "Error loading dialog template: {error}" : "Грешка при учитавању шаблона дијалога: {error}",
    "No tags selected for deletion." : "Нема ознака за брисање.",
    "unknown text" : "непознат текст",
    "Hello world!" : "Здраво свете!",
    "sunny" : "сунчано",
    "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
    "Hello {name}" : "Здраво {name}",
    "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
    "Updating {productName} to version {version}, this may take a while." : "Надограђујем {productName} на издање {version}. Ово би могло да потраје.",
    "Please reload the page." : "Поново учитајте страницу.",
    "The update was unsuccessful. " : "Ажурирање није успело.",
    "The update was successful. There were warnings." : "Ажурирање је успело. Било је упозорења.",
    "The update was successful. Redirecting you to ownCloud now." : "Ажурирање је успело. Преусмеравам вас на оунКлауд.",
    "Searching other places" : "Претражујем остала места",
    "Personal" : "Лично",
    "Users" : "Корисници",
    "Apps" : "Апликације",
    "Admin" : "Администрација",
    "Help" : "Помоћ",
    "Error loading tags" : "Грешка при учитавању ознака",
    "Tag already exists" : "Ознака већ постоји",
    "Error deleting tag(s)" : "Грешка при брисању ознака",
    "Error tagging" : "Грешка означавања",
    "Error untagging" : "Грешка при скидању ознака",
    "Error favoriting" : "Грешка при постављању омиљеног",
    "Error unfavoriting" : "Грешка при укидању омиљеног",
    "Access forbidden" : "Забрањен приступ",
    "File not found" : "Фајл није нађен",
    "The specified document has not been found on the server." : "Наведени документ није нађен на серверу.",
    "You can click here to return to %s." : "Кликните овде да се вратите на %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Поздрав,\n\nсамо вас обавештавам да %s дели %s са вама.\nПогледајте: %s\n\n",
    "The share will expire on %s." : "Дељење истиче %s.",
    "Cheers!" : "Здраво!",
    "Internal Server Error" : "Унутрашња грешка сервера",
    "The server encountered an internal error and was unable to complete your request." : "Због интерне грешке на серверу, ваш захтев није могао бити довршен.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Контактирајте администратора ако се грешка понови и укључите у извештај техничке појединости наведене испод.",
    "More details can be found in the server log." : "Више детаља се може наћи у дневнику сервера.",
    "Technical details" : "Технички детаљи",
    "Remote Address: %s" : "Удаљена адреса: %s",
    "Request ID: %s" : "ИД захтева: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Кôд: %s",
    "Message: %s" : "Порука: %s",
    "File: %s" : "Фајл: %s",
    "Line: %s" : "Линија: %s",
    "Trace" : "Траг",
    "Security warning" : "Безбедносно упозорење",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Информације о томе како исправно подесити серверможете наћи у<a href=\"%s\" target=\"_blank\">документацији</a>.",
    "Create an <strong>admin account</strong>" : "Направи <strong>административни налог</strong>",
    "Username" : "Корисничко име",
    "Storage & database" : "Складиште и база података",
    "Data folder" : "Фацикла података",
    "Configure the database" : "Подешавање базе",
    "Only %s is available." : "Само %s је доступна.",
    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне ПХП модуле за избор других врста база података.",
    "For more details check out the documentation." : "За више детаља погледајте документацију.",
    "Database user" : "Корисник базе",
    "Database password" : "Лозинка базе",
    "Database name" : "Назив базе",
    "Database tablespace" : "Радни простор базе података",
    "Database host" : "Домаћин базе",
    "Performance warning" : "Упозорење о перформансама",
    "SQLite will be used as database." : "СКуЛајт ће бити коришћен за базу података.",
    "For larger installations we recommend to choose a different database backend." : "За веће инсталације препоручујемо да изаберете другу позадину базе података.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Нарочито ако се користи клијент програм у графичком окружењу, коришћење СКуЛајта није препоручљиво.",
    "Finish setup" : "Заврши подешавање",
    "Finishing …" : "Завршавам…",
    "Need help?" : "Треба вам помоћ?",
    "See the documentation" : "Погледајте документацију",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Поздрав,<br><br>само вас обавештавам да %s дели <strong>%s</strong> са вама.<br><a href=\"%s\">Погледајте!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ова апликација захтева Јава скрипт за исправан рад. {linkstart}Омогућите Јава скрипт{linkend} и поново учитајте страницу.",
    "Log out" : "Одјава",
    "Search" : "Претражи",
    "Server side authentication failed!" : "Аутентификација на серверу није успела!",
    "Please contact your administrator." : "Контактирајте вашег администратора.",
    "An internal error occured." : "Дошло је до интерне грешке.",
    "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
    "Log in" : "Пријава",
    "Alternative Logins" : "Алтернативне пријаве",
    "Use the following link to reset your password: {link}" : "Употребите следећу везу да ресетујете своју лозинку: {link}",
    "New password" : "Нова лозинка",
    "New Password" : "Нова лозинка",
    "Reset password" : "Ресетуј лозинку",
    "This ownCloud instance is currently in single user mode." : "Овај оунКлауд тренутно ради у режиму једног корисника.",
    "This means only administrators can use the instance." : "То значи да га могу користити само администратори.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
    "Thank you for your patience." : "Хвала вам на стрпљењу.",
    "You are accessing the server from an untrusted domain." : "Приступате серверу са непоузданог домена.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Зависно од ваших подешавања, као администратор можете употребити дугме испод да потврдите поузданост домена.",
    "Add \"%s\" as trusted domain" : "Додај „%s“ као поуздан домен",
    "The theme %s has been disabled." : "Тема %s је онемогућена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Проверите да ли сте направили резервну копију фасцикли са подешавањима и подацима пре него што наставите.",
    "Start update" : "Почни надоградњу",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Да избегнете прекорачење времена одзива на већим инсталацијама, можете покренути следећу команду у инсталационом директоријуму:",
    "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања а то може потрајати.",
    "This page will refresh itself when the %s instance is available again." : "Ова страница ће се сама освежити када %s постане поново доступан."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
